@@ -1,9 +1,7 @@
 /*
  * %kadu copyright begin%
- * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
- * Copyright 2007, 2008, 2009, 2010, 2011, 2013 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * Copyright 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
- * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
+ * Copyright 2009, 2010, 2011, 2013, 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
  * %kadu copyright end%
  *
  * This program is free software; you can redistribute it and/or
@@ -20,8 +18,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef OPEN_CHAT_WITH_RUNNER_H
-#define OPEN_CHAT_WITH_RUNNER_H
+#pragma once
 
 #include "buddies/buddy-list.h"
 
@@ -34,5 +31,3 @@ public:
 	virtual BuddyList matchingContacts(const QString &query) = 0;
 
 };
-
-#endif // OPEN_CHAT_WITH_RUNNER_H
